aboutsummaryrefslogtreecommitdiffstats
path: root/libbe/storage/vcs
diff options
context:
space:
mode:
Diffstat (limited to 'libbe/storage/vcs')
-rw-r--r--libbe/storage/vcs/base.py6
1 files changed, 4 insertions, 2 deletions
diff --git a/libbe/storage/vcs/base.py b/libbe/storage/vcs/base.py
index fc3427a..662fc30 100644
--- a/libbe/storage/vcs/base.py
+++ b/libbe/storage/vcs/base.py
@@ -481,9 +481,9 @@ os.listdir(self.get_path("bugs")):
path = os.path.abspath('.')
return path
- def _vcs_init(self):
+ def _vcs_init(self, path):
"""
Begin versioning the tree based at self.repo.
"""
pass
@@ -615,6 +615,8 @@ os.listdir(self.get_path("bugs")):
Begin versioning the tree based at self.repo.
Also roots the vcs at path.
"""
+ if not os.path.exists(self.repo) or not os.path.isdir(self.repo):
+ raise VCSUnableToRoot(self)
self._vcs_init(self.repo)
self.root()
os.mkdir(self.be_dir)
@@ -481,9 +481,9 @@ os.listdir(self.get_path("bugs")):
"""
- Begin versioning the tree based at self.repo.
+ Begin versioning the tree based at path.
"""
pass